Telescope workflows
_________

A telescope is a type of workflow used to ingest data from different data sources, and to run workflows that process and
output data to other places. Workflows are built on top of Apache Airflow's DAGs.

.. toctree::
    :maxdepth: 1

    crossref_events
    crossref_metadata
    google_analytics
    google_books
    jstor
    oapen_metadata
    irus_oapen
    irus_fulcrum
    onix
    thoth
    ucl_discovery